@@ -37,7 +37,7 @@ cff_gha_update <- function(path = ".",
 
   newfile <- file.path(destdir, "update-citation-cff.yaml")
 
-  if (!file.exists(newfile) | isTRUE(overwrite)) {
+  if (!file.exists(newfile) || isTRUE(overwrite)) {
     message(crayon::blue("Installing update-citation-cff.yaml"))
     file.copy(system.file("yaml/update-citation-cff.yaml",
       package = "cffr"
