@@ -49,38 +49,46 @@ parse_package_meta <- function(desc_path) {
   meta
 }
 
-
-#' Used for creating an auto preferred-citation from an
-#' cff object if not present
-#' It mocks citation(auto = meta) of base R
-#' @noRd
-parse_preferred_auto <- function(cffobjend) {
-  valid <- cff_schema_definitions_refs()
-
-  pref <- cffobjend[names(cffobjend) %in%
-    valid]
-
-  pref$type <- "manual"
-
-  # Handle year
-
-  date_rel <- pref[["date-released"]]
-
-  if (is.null(date_rel)) {
-    year <- format(Sys.Date(), "%Y")
-  } else {
-    year <- format(as.Date(pref[["date-released"]]), "%Y")
-  }
-
-  pref$year <- year
-
-  # Order and output
-  ordernames <- unique(c("type", "title", "authors", names(pref)))
-  pref <- pref[unique(c(ordernames, "identifiers"))]
-  pref <- as.cff(pref)
-
-  pref
-}
+# DEPRECATED
+# Used for creating an auto preferred-citation from an
+# cff object if not present
+# It mocks citation(auto = meta) of base R
+# parse_preferred_auto <- function(cffobjend) {
+#   valid <- cff_schema_definitions_refs()
+#
+#   pref <- cffobjend[names(cffobjend) %in%
+#     valid]
+#
+#   pref$type <- "manual"
+#
+#   # Handle year
+#
+#   date_rel <- pref[["date-released"]]
+#
+#   if (is.null(date_rel)) {
+#     year <- format(Sys.Date(), "%Y")
+#   } else {
+#     year <- format(as.Date(pref[["date-released"]]), "%Y")
+#   }
+#
+#   pref$year <- year
+#   pref$notes <- NULL
+#   if (!is.null(pref$version)) {
+#     pref$notes <- paste("R package version", pref$version)
+#   }
+#   # If it has a repository (CRAN) use that as url
+#   if (!is.null(pref$repository)) pref$url <- pref$repository
+#
+#   # Order and output
+#   ordernames <- c(
+#     "type", "title", "authors", "year",
+#     "notes", "url"
+#   )
+#   pref <- pref[ordernames]
+#   pref <- as.cff(pref)
+#
+#   pref
+# }
 ## Building blocks ----
 
 #' BB for doi
@@ -113,6 +121,8 @@ building_doi <- function(parse_cit) {
     doi = clean_str(doi),
     identifiers = identifiers
   )
+
+  return(doi_list)
 }
 
 #' BB for month
@@ -181,6 +191,8 @@ building_url <- function(parse_cit) {
     url = clean_str(url),
     identifiers = identifiers
   )
+
+  return(url_list)
 }
 
 #' BB for other persons
