@@ -1,9 +1,6 @@
 test_that("Test citations with installed packages", {
   installed <- as.character(installed.packages()[, 1])
-  inst <- c(
-    "base", "utils", "jsonlite", "jsonvalidate", "rmarkdown",
-    "thisisanerrorpackage", "DCluster", "surveillance"
-  )
+  inst <- c("base", "jsonlite", "rmarkdown")
   for (i in seq_len(length(inst))) {
     if (inst[i] %in% installed) {
       desc <- cff_create(inst[i])
